summaryrefslogtreecommitdiff
path: root/examples/poiseulle_particles_2d_ibm_gpu
diff options
context:
space:
mode:
authorClaudius "keldu" Holeksa <mail@keldu.de>2026-08-14 23:43:54 +0200
committerClaudius "keldu" Holeksa <mail@keldu.de>2026-08-14 23:43:54 +0200
commit0e9322fe0d024a06f23430285a055c16cf1e3eeb (patch)
tree657a33098c96b14c0e09748c6b9d4a7e9cd16160 /examples/poiseulle_particles_2d_ibm_gpu
parent0d15416f60491bd4d17bd8b45a9487c98b8132b0 (diff)
parentc634aac438972b7bafb5fbbeba7962d174cc0d03 (diff)
downloadlibs-lbm-0e9322fe0d024a06f23430285a055c16cf1e3eeb.tar.gz
Merge branch 'dev'
Diffstat (limited to 'examples/poiseulle_particles_2d_ibm_gpu')
-rw-r--r--examples/poiseulle_particles_2d_ibm_gpu/sim.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/poiseulle_particles_2d_ibm_gpu/sim.cpp b/examples/poiseulle_particles_2d_ibm_gpu/sim.cpp
index 640c9ab..d63515d 100644
--- a/examples/poiseulle_particles_2d_ibm_gpu/sim.cpp
+++ b/examples/poiseulle_particles_2d_ibm_gpu/sim.cpp
@@ -46,7 +46,7 @@ using RhoChunk = Chunk<Scalar<T>, 0u, dim_x, dim_y>;
template<typename T, typename Desc>
using MacroStruct = Struct<
- Member<VelChunk<T,Desc>, "velocity">,
+ Member<VelChunk<T,Desc>, "momentum">,
Member<RhoChunk<T>, "density">,
Member<VelChunk<T,Desc>, "force">
>;
@@ -113,7 +113,7 @@ saw::error_or<void> setup_initial_conditions(
//
auto& df_f = fields.template get<"dfs_old">();
auto& rho_f = macros.template get<"density">();
- auto& vel_f = macros.template get<"velocity">();
+ auto& vel_f = macros.template get<"momentum">();
auto& force_f = macros.template get<"force">();
iterator<Desc::D>::apply(
@@ -218,7 +218,7 @@ saw::error_or<void> step(
q.submit([&](acpp::sycl::handler& h){
h.parallel_for(acpp::sycl::range<1u>{1u}, [=](acpp::sycl::id<1u> idx){
- auto& vel_f = macros.template get<"velocity">();
+ auto& vel_f = macros.template get<"momentum">();
auto& dense_f = macros.template get<"density">();
auto& ps = particles;